from __future__ import unicode_literals

import sys

from django.utils.safestring import mark_safe

if sys.version_info[0] > 2:
    from future.types.newstr import unicode
    from future.standard_library import install_aliases

    # For the future library so we can be Python 2 and 3 compatible
    install_aliases()


def join_url(*path_parts):
    path_pieces = []
    path_parts = list(path_parts)

    is_root = False
    if path_parts[0] and path_parts[0][0] == '/':
        is_root = True

    for path_part in path_parts:
        if path_part:
            if isinstance(path_part, (str, unicode)) and '/' in path_part:
                pieces = path_part.split('/')
                path_pieces.append(join_url(*pieces))

            elif isinstance(path_part, (str, unicode)) and '/' not in path_part:
                path_pieces.append(path_part)

    path_string = '/'.join(path_pieces)

    if is_root:
        path_string = '/%s' % path_string

    return path_string


def render_css(css_files):
    retn_list = []

    if not isinstance(css_files, list):
        css_files = [css_files]

    for css_file in css_files:
        retn_list.append('<link rel="stylesheet" href="%s"/>' % css_file)

    return mark_safe('\n'.join(retn_list))


def render_javascript(javascripts):
    retn_list = []

    if not isinstance(javascripts, list):
        javascripts = [javascripts]

    for javascript in javascripts:
        retn_list.append('<script src="%s" type="text/javascript"></script>' % javascript)

    return mark_safe('\n'.join(retn_list))



"""
@copyright Amos Vryhof

"""
from django import template
from django.conf import settings

from .utils import join_url, render_css, render_javascript

register = template.Library()

static_root = settings.STATIC_URL


@register.simple_tag
def fontawesome4_css():
    font_awesome_url = join_url(static_root, 'css', 'font-awesome-4.min.css')

    return render_css(font_awesome_url)


@register.simple_tag
def fontawesome5_css(shim=False):
    font_awesome_urls = [join_url(static_root, 'css', 'all.min.css')]

    if shim:
        font_awesome_urls.append(join_url(static_root, 'css', 'v4-shims.min.css'))

    return render_css(font_awesome_urls)


@register.simple_tag
def fontawesome5_javascript(shim=False):
    fa_js_url = join_url(static_root, 'js', 'fontawesome.min.js')
    fa_js_all = join_url(static_root, 'js', 'all.min.js')

    javascripts = [fa_js_url, fa_js_all]

    if shim:
        javascripts.append(join_url(static_root, 'js', 'v4-shims.min.js'))

    return render_javascript(javascripts)


@register.simple_tag
def modernizr():
    modernizr_url = join_url(static_root, 'js', 'modernizr.js')

    return render_javascript(modernizr_url)


@register.simple_tag
def ieshiv():
    ieshiv_url = join_url(static_root, 'js', 'ieshiv.js')

    return render_javascript(ieshiv_url)
